@@ -2,20 +2,21 @@
 
 function activities_process_commands($cmd,$opts)
 {
-  switch( $cmd )
-    {
-    case 'LIST':
-      return activities_list($opts);
-    }
+  switch( $cmd ) {
+  case 'LIST':
+    return activities_list($opts);
+  }
 }
 
 function activities_list($opts)
 {
   if( count($opts) == 1 && strtolower($opts[0]) == 'help' ) {
-echo <<<EOT
-usage: list
-list activities\n
-EOT;    
+    echo <<<EOT
+      usage: list
+      list activities
+
+EOT;
+    return;
   }
 
   $req = new cms_http_request();
@@ -25,17 +26,12 @@ EOT;
 
   $res = $req->execute();
   $tmp = json_decode($res,TRUE);
-  if( isset($tmp->_status) && $tmp->_status != 'OK' )
-    {
-      $msg = $tmp->_status;
-      if( isset($tmp->_message) )
-	{
-	  $msg .= ': '.$tmp->_message;
-	}
-      set_errormsg($msg);
-      return FALSE;
-    }
-
+  if( isset($tmp->_status) && $tmp->_status != 'OK' ) {
+    $msg = $tmp->_status;
+    if( isset($tmp->_message) ) $msg .= ': '.$tmp->_message;
+    set_errormsg($msg);
+    return FALSE;
+  }
   print_r($tmp); // woot done.
   return TRUE;
 }
